@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2015-2017, Intel Corporation
+* Copyright (c) 2015-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -29,6 +29,7 @@
 
 #include "mhw_render_generic.h"
 #include "mhw_render_hwcmd_g11_X.h"
+#include "mhw_state_heap_g11.h"
 
 typedef struct MHW_RENDER_ENGINE_L3_CACHE_SETTINGS_G11 : MHW_RENDER_ENGINE_L3_CACHE_SETTINGS
 {
@@ -97,6 +98,37 @@ public:
         return &m_mmioRegisters;
     }
 
+    //!
+    //! \brief    Get AVS sampler state Inc unit
+    //! \details  Get AVS sampler state Inc unit
+    //! \return   [out] uint32_t
+    //!           AVS sampler unit.
+    virtual uint32_t GetSamplerStateAVSIncUnit() { return MHW_SAMPLER_STATE_AVS_INC_G11; }
+
+    //!
+    //! \brief    Get Conv sampler state Inc unit
+    //! \details  Get Conv sampler state Inc unit
+    //! \return   [out] uint32_t
+    //!           Conv sampler unit.
+    virtual uint32_t GetSamplerStateConvIncUnit() { return MHW_SAMPLER_STATE_CONV_INC_G11; }
+
+    //!
+    //! \brief    Get the sampler height and width align unit
+    //! \details  NV12 format needs the width and height to be a multiple of some unit
+    //! \param    [in] bool
+    //!           true if AVS sampler, false otherwise
+    //! \param    [in, out] uint32_t
+    //!           weight align unit
+    //! \param    [in, out] uint32_t
+    //!           height align unit
+    virtual void GetSamplerResolutionAlignUnit(bool isAVSSampler, uint32_t &widthAlignUnit, uint32_t &heightAlignUnit)
+    {
+        // enable 2 plane NV12 when width is not multiple of 2 or height is
+        // not multiple of 4. For AVS sampler, no limitation for 4 alignment.
+        widthAlignUnit  = isAVSSampler ? MHW_AVS_SAMPLER_WIDTH_ALIGN_UNIT : MHW_SAMPLER_WIDTH_ALIGN_UNIT_G11;
+        heightAlignUnit = isAVSSampler ? MHW_AVS_SAMPLER_HEIGHT_ALIGN_UNIT : MHW_SAMPLER_HEIGHT_ALIGN_UNIT_G11;
+    }
+
 protected:
     MHW_RENDER_ENGINE_L3_CACHE_CONFIG_G11   m_l3CacheConfig;
 
