@@ -34,9 +34,7 @@
 #include <va/va_backend_vpp.h>
 #include "vphal.h"
 #include "mos_os.h"
-
-// Maximum primary surface number in VP
-#define VP_MAX_PRIMARY_SURFS     1
+#include "ddi_vp_functions.h"
 
 //For Gen8, only support max 16k-32
 #define VP_MAX_PIC_WIDTH_Gen8    16352
@@ -48,70 +46,8 @@
 #define VP_MIN_PIC_WIDTH         16
 #define VP_MIN_PIC_HEIGHT        16
 
-// surface flag : 1 secure;  0 clear
-#if (VA_MAJOR_VERSION < 1)
-#define VPHAL_SURFACE_ENCRYPTION_FLAG 0x80000000
-#else
-#define VPHAL_SURFACE_ENCRYPTION_FLAG 0x00000001
-#endif
 #define NUM_SURFS 1
 
-#if (_DEBUG || _RELEASE_INTERNAL)
-typedef struct _DDI_VP_DUMP_PARAM
-{
-    VAProcPipelineParameterBuffer             *pPipelineParamBuffers[VPHAL_MAX_SOURCES];
-    MOS_FORMAT                                SrcFormat[VPHAL_MAX_SOURCES];
-    MOS_FORMAT                                TargetFormat[VPHAL_MAX_TARGETS];
-} DDI_VP_DUMP_PARAM, *PDDI_VP_DUMP_PARAM;
-#endif //(_DEBUG || _RELEASE_INTERNAL)
-
-typedef struct _DDI_VP_FRAMEID_TRACER
-{
-    MOS_LINUX_BO                       *pLastSrcSurfBo;
-    MOS_LINUX_BO                       *pLastBwdSurfBo;
-
-    uint32_t                                   uiLastSrcSurfFrameID;
-    uint32_t                                   uiLastBwdSurfFrameID;
-
-    uint32_t                                   uiFrameIndex;
-
-    uint32_t                                   uiLastSampleType;
-} DDI_VP_FRAMEID_TRACER;
-
-//core structure for VP DDI
-typedef struct DDI_VP_CONTEXT
-{
-    // VPHAL internal structure
-    MOS_CONTEXT                               MosDrvCtx;
-    VpBase                                    *pVpHal;
-    VPHAL_RENDER_PARAMS                       *pVpHalRenderParams;
-
-    DdiCpInterface                            *pCpDdiInterface;
-
-    // target surface id
-    VASurfaceID                               TargetSurfID;
-
-    // Primary surface number
-    int32_t                                   iPriSurfs;
-
-    DDI_VP_FRAMEID_TRACER                     FrameIDTracer;
-
-#if (_DEBUG || _RELEASE_INTERNAL)
-    DDI_VP_DUMP_PARAM                         *pCurVpDumpDDIParam;
-    DDI_VP_DUMP_PARAM                         *pPreVpDumpDDIParam;
-    FILE                                      *fpDumpFile;
-#endif //(_DEBUG || _RELEASE_INTERNAL)
-
-} DDI_VP_CONTEXT, *PDDI_VP_CONTEXT;
-
-typedef struct _DDI_VP_STATE
-{
-    bool      bProcampEnable;
-    bool      bDeinterlaceEnable;
-    bool      bDenoiseEnable;
-    bool      bIEFEnable;
-} DDI_VP_STATE;
-
 // public APIs
 
 VAStatus DdiVp_CreateContext(
