@@ -51,7 +51,7 @@
 #include "mhw_blt_legacy.h"
 #include "mhw_vdbox_avp_g12_X.h"
 
-#ifdef IGFX_VDENC_INTERFACE_EXT_SUPPORT
+#ifdef _MEDIA_RESERVED
 #include "mhw_vdbox_vdenc_g12_X_ext.h"
 #endif
 
@@ -61,7 +61,7 @@
 #include "codechal_hw_g12_X.h"
 #ifdef _AVC_DECODE_SUPPORTED
 #include "codechal_decode_avc_g12.h"
-#ifdef _APOGEIOS_SUPPORTED
+#ifdef _MEDIA_RESERVED
 #include "decode_avc_pipeline_adapter_m12.h"
 #endif
 #endif
@@ -77,7 +77,7 @@
 
 #ifdef _MPEG2_DECODE_SUPPORTED
 #include "codechal_decode_mpeg2_g12.h"
-#ifdef _APOGEIOS_SUPPORTED
+#ifdef _MEDIA_RESERVED
 #include "decode_mpeg2_pipeline_adapter_m12.h"
 #endif
 #endif
@@ -96,7 +96,7 @@
 
 #ifdef _JPEG_ENCODE_SUPPORTED
 #include "codechal_encode_jpeg_g12.h"
-#ifdef _APOGEIOS_SUPPORTED
+#ifdef _MEDIA_RESERVED
 #include "decode_jpeg_pipeline_adapter_m12.h"
 #endif
 #endif
@@ -110,7 +110,7 @@
 
 #ifdef _VP9_ENCODE_VDENC_SUPPORTED
 #include "codechal_vdenc_vp9_g12.h"
-#ifdef _APOGEIOS_SUPPORTED
+#ifdef _MEDIA_RESERVED
 #include "encode_vp9_vdenc_pipeline_adapter_m12.h"
 #endif
 #endif
@@ -125,7 +125,7 @@
 #endif
 #ifdef _HEVC_ENCODE_VDENC_SUPPORTED
 #include "codechal_vdenc_hevc_g12.h"
-#ifdef _APOGEIOS_SUPPORTED
+#ifdef _MEDIA_RESERVED
 #include "decode_hevc_pipeline_adapter_m12.h"
 #include "decode_vp9_pipeline_adapter_m12.h"
 #endif
@@ -154,8 +154,6 @@
 class MhwInterfacesG12Tgllp : public MhwInterfaces
 {
 public:
-    MhwVdboxAvpInterface *m_avpInterface = nullptr;
-
     using Mi = MhwMiInterfaceG12;
     using Cp = MhwCpInterface;
     using Render = MhwRenderInterfaceG12;
@@ -165,7 +163,7 @@ public:
     using Hcp = MhwVdboxHcpInterfaceG12;
     using Huc = MhwVdboxHucInterfaceG12;
     using Avp = MhwVdboxAvpInterfaceG12;
-#ifdef IGFX_VDENC_INTERFACE_EXT_SUPPORT
+#ifdef _MEDIA_RESERVED
     using Vdenc = MhwVdboxVdencInterfaceG12ExtX;
 #else
     using Vdenc = MhwVdboxVdencInterfaceG12X;
