@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2019-2022, Intel Corporation
+* Copyright (c) 2019-2024, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -35,16 +35,10 @@ namespace decode
     {
         for (uint8_t i = 0; i < av1DefaultCdfTableNum; i++)
         {
-            if (!m_allocator->ResourceIsNull(&m_tmpCdfBuffers[i]->OsResource))
-            {
-                m_allocator->Destroy(m_tmpCdfBuffers[i]);
-            }
-
             if (!m_allocator->ResourceIsNull(&m_defaultCdfBuffers[i]->OsResource))
             {
                 m_allocator->Destroy(m_defaultCdfBuffers[i]);
             }
-
         }
         if (m_usingDummyWl == true)
         {
@@ -111,6 +105,12 @@ namespace decode
         m_av1PicParams  = static_cast<CodecAv1PicParams*>(decodeParams->m_picParams);
         DECODE_CHK_NULL(m_av1PicParams);
 
+        if (decodeParams->m_destSurface->OsResource.Format == Format_P010 &&
+            m_osInterface->pfnIsMismatchOrderProgrammingSupported())
+        {
+            m_bitDepth = 10;
+        }
+
         // Do error detection and concealment
         DECODE_CHK_STATUS(ErrorDetectAndConceal());
 
@@ -182,7 +182,8 @@ namespace decode
         
         // Reference Frame
         if (m_av1PicParams->m_picInfoFlags.m_fields.m_frameType != keyFrame && 
-            m_av1PicParams->m_picInfoFlags.m_fields.m_frameType != intraOnlyFrame)
+            m_av1PicParams->m_picInfoFlags.m_fields.m_frameType != intraOnlyFrame &&
+            !m_osInterface->pfnIsMismatchOrderProgrammingSupported())
         {
             for (int i = 0; i < 8; i++)
             {
@@ -654,7 +655,18 @@ namespace decode
 
         DECODE_CHK_STATUS(UpdateDefaultCdfTable());
         DECODE_CHK_STATUS(m_refFrames.UpdatePicture(*m_av1PicParams));
-        DECODE_CHK_STATUS(m_tempBuffers.UpdatePicture(m_av1PicParams->m_currPic.FrameIdx, m_refFrameIndexList));
+        if (m_osInterface->pfnIsMismatchOrderProgrammingSupported())
+        {
+            for (auto &refFrameIdx : m_refFrameIndexList)
+            {
+                DECODE_CHK_STATUS(m_tempBuffers.ActiveCurBuffer(refFrameIdx));
+            }
+            DECODE_CHK_STATUS(m_tempBuffers.ReActiveCurBuffer(m_av1PicParams->m_currPic.FrameIdx, m_refFrameIndexList));
+        }
+        else
+        {
+            DECODE_CHK_STATUS(m_tempBuffers.UpdatePicture(m_av1PicParams->m_currPic.FrameIdx, m_refFrameIndexList));
+        }
         DECODE_CHK_STATUS(SetSegmentData(*m_av1PicParams));
 
         DECODE_CHK_STATUS(CalculateGlobalMotionParams());
@@ -954,20 +966,16 @@ namespace decode
         {
             for (uint8_t index = 0; index < av1DefaultCdfTableNum; index++)
             {
-                m_tmpCdfBuffers[index] = m_allocator->AllocateBuffer(
+                m_defaultCdfBuffers[index] = m_allocator->AllocateBuffer(
                     MOS_ALIGN_CEIL(m_cdfMaxNumBytes, CODECHAL_PAGE_SIZE), "TempCdfTableBuffer",
                     resourceInternalRead, lockableVideoMem);
-                DECODE_CHK_NULL(m_tmpCdfBuffers[index]);
+                DECODE_CHK_NULL(m_defaultCdfBuffers[index]);
 
-                auto data = (uint16_t *)m_allocator->LockResourceForWrite(&m_tmpCdfBuffers[index]->OsResource);
+                auto data = (uint16_t *)m_allocator->LockResourceForWrite(&m_defaultCdfBuffers[index]->OsResource);
                 DECODE_CHK_NULL(data);
-
+                
                 // reset all CDF tables to default values
                 DECODE_CHK_STATUS(InitDefaultFrameContextBuffer(data, index));
-                m_defaultCdfBuffers[index] = m_allocator->AllocateBuffer(
-                    MOS_ALIGN_CEIL(m_cdfMaxNumBytes, CODECHAL_PAGE_SIZE), "m_defaultCdfBuffers",
-                    resourceInternalRead, notLockableVideoMem);
-                DECODE_CHK_NULL(m_defaultCdfBuffers[index]);
             }
 
             m_defaultFcInitialized = true;//set only once, won't set again
