@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2021-2023, Intel Corporation
+* Copyright (c) 2021-2024, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -116,6 +116,8 @@ namespace decode{
         m_allocator = m_pipeline ->GetDecodeAllocator();
         DECODE_CHK_NULL(m_allocator);
 
+        MOS_ZeroMemory(m_refSurface, sizeof(m_refSurface));
+
         return MOS_STATUS_SUCCESS;
     }
 
@@ -125,10 +127,8 @@ namespace decode{
 
         DECODE_CHK_STATUS(GetChromaFormat());
 
-#ifdef _MMC_SUPPORTED
         m_mmcState = m_av1Pipeline->GetMmcState();
         DECODE_CHK_NULL(m_mmcState);
-#endif
 
         DECODE_CHK_STATUS(SetRowstoreCachingOffsets());
 
@@ -660,7 +660,7 @@ namespace decode{
         for (uint8_t i = 0; i < av1MaxSegments; i++)
         {
             par.currentSegmentId = i;
-            m_avpItf->MHW_ADDCMD_F(AVP_SEGMENT_STATE)(&cmdBuffer);
+            DECODE_CHK_STATUS(m_avpItf->MHW_ADDCMD_F(AVP_SEGMENT_STATE)(&cmdBuffer));
 
             if (m_av1PicParams->m_av1SegData.m_enabled == 0)
             {
@@ -894,12 +894,10 @@ namespace decode{
             }
         }
 
-#ifdef _MMC_SUPPORTED
         if (m_mmcState && m_mmcState->IsMmcEnabled())
         {
             DECODE_CHK_STATUS(m_mmcState->GetSurfaceMmcState(const_cast<PMOS_SURFACE>(&m_av1BasicFeature->m_destSurface), &params.mmcStatePreDeblock));
         };
-#endif
 
 #if USE_CODECHAL_DEBUG_TOOL
         DECODE_CHK_STATUS(DumpResources(refSize));
@@ -1064,7 +1062,17 @@ namespace decode{
 
             if (!AV1_KEY_OR_INRA_FRAME(m_av1PicParams->m_picInfoFlags.m_fields.m_frameType))
             {
-                uint8_t refPicIndex = refFrameList[m_av1PicParams->m_refFrameIdx[i]].FrameIdx;
+                uint8_t refPicIndex = 0xFF;
+                if (m_av1PicParams->m_refFrameIdx[i] < av1TotalRefsPerFrame &&
+                    refFrameList[m_av1PicParams->m_refFrameIdx[i]].FrameIdx < CODECHAL_MAX_DPB_NUM_AV1)
+                {
+                    refPicIndex = refFrameList[m_av1PicParams->m_refFrameIdx[i]].FrameIdx;
+                }
+                else
+                {
+                    DECODE_CHK_STATUS(m_av1BasicFeature->m_refFrames.GetValidReferenceIndex(&refPicIndex));
+                }
+
                 horizontalScaleFactor = (m_refList[refPicIndex]->m_frameWidth * m_av1ScalingFactor + (curFrameWidth >> 1)) / curFrameWidth;
                 verticalScaleFactor   = (m_refList[refPicIndex]->m_frameHeight * m_av1ScalingFactor + (curFrameHeight >> 1)) / curFrameHeight;
 
@@ -1101,7 +1109,6 @@ namespace decode{
         DECODE_FUNC_CALL();
 
         DECODE_CHK_NULL(surface);
-#ifdef _MMC_SUPPORTED
         DECODE_CHK_NULL(m_mmcState);
 
         if (m_mmcState->IsMmcEnabled())
@@ -1111,7 +1118,6 @@ namespace decode{
             DECODE_CHK_STATUS(m_mmcState->GetSurfaceMmcFormat(surface, &compressionFormat));
         }
         else
-#endif
         {
             mmcState = MOS_MEMCOMP_DISABLED;
         }
@@ -1140,7 +1146,7 @@ namespace decode{
                 MOS_ZeroMemory(&refSurface, sizeof(MOS_SURFACE));
                 refSurface.OsResource = *(par.refs[n + lastFrame]);
                 DECODE_CHK_STATUS(m_allocator->GetSurfaceInfo(&refSurface));
-                std::string refSurfName = "RefSurf[" + std::to_string(static_cast<uint32_t>(n + lastFrame)) + "]";
+                std::string refSurfName = "RefSurf[" + std::to_string(static_cast<uint32_t>(n)) + "]";
                 DECODE_CHK_STATUS(debugInterface->DumpYUVSurface(
                     &refSurface,
                     CodechalDbgAttr::attrDecodeReferenceSurfaces,
