@@ -466,9 +466,15 @@ MOS_STATUS Av1BasicFeature::GetTrackedBuffers()
 Av1StreamIn *Av1BasicFeature::GetStreamIn()
 {
     m_streamIn.Init(this, this->m_allocator, this->m_osInterface);
+    
     return &m_streamIn;
 }
 
+MediaFeatureManager *Av1BasicFeature::GetFeatureManager()
+{
+    return m_featureManager;
+}
+
 MOS_STATUS Av1BasicFeature::GetSurfaceMmcInfo(PMOS_SURFACE surface, MOS_MEMCOMP_STATE& mmcState, uint32_t& compressionFormat) const
 {
     ENCODE_FUNC_CALL();
@@ -623,6 +629,7 @@ MOS_STATUS SyntaxElementCdfTableInit(
     uint16_t                    *ctxBuffer,
     SyntaxElementCdfTableLayout SyntaxElement)
 {
+    ENCODE_FUNC_CALL();
     ENCODE_CHK_NULL_RETURN(ctxBuffer);
     ENCODE_CHK_NULL_RETURN(SyntaxElement.m_srcInitBuffer);
 
@@ -654,6 +661,7 @@ MOS_STATUS SyntaxElementCdfTableInit(
 
 MHW_SETPAR_DECL_SRC(VDENC_PIPE_MODE_SELECT, Av1BasicFeature)
 {
+    ENCODE_FUNC_CALL();
     params.standardSelect    = 3;  // av1
     params.chromaType        = m_outputChromaFormat;
     params.bitDepthMinus8    = m_is10Bit ? 2 : 0;
@@ -684,6 +692,7 @@ MHW_SETPAR_DECL_SRC(VDENC_PIPE_MODE_SELECT, Av1BasicFeature)
 
 MHW_SETPAR_DECL_SRC(VDENC_SRC_SURFACE_STATE, Av1BasicFeature)
 {
+    ENCODE_FUNC_CALL();
     params.pitch                         = m_rawSurfaceToEnc->dwPitch;
     params.tileType                      = m_rawSurfaceToEnc->TileType;
     params.tileModeGmm                   = m_rawSurfaceToEnc->TileModeGMM;
@@ -702,6 +711,7 @@ MHW_SETPAR_DECL_SRC(VDENC_SRC_SURFACE_STATE, Av1BasicFeature)
 
 MHW_SETPAR_DECL_SRC(VDENC_REF_SURFACE_STATE, Av1BasicFeature)
 {
+    ENCODE_FUNC_CALL();
     auto surface = &m_reconSurface;
     if (!AV1_KEY_OR_INRA_FRAME(m_av1PicParams->PicFlags.fields.frame_type))
     {
@@ -748,6 +758,7 @@ MHW_SETPAR_DECL_SRC(VDENC_REF_SURFACE_STATE, Av1BasicFeature)
 
 MHW_SETPAR_DECL_SRC(VDENC_DS_REF_SURFACE_STATE, Av1BasicFeature)
 {
+    ENCODE_FUNC_CALL();
     auto surface8x = m_8xDSSurface;
     if (!AV1_KEY_OR_INRA_FRAME(m_av1PicParams->PicFlags.fields.frame_type))
     {
@@ -782,7 +793,8 @@ MHW_SETPAR_DECL_SRC(VDENC_DS_REF_SURFACE_STATE, Av1BasicFeature)
 }
 
 MHW_SETPAR_DECL_SRC(VDENC_PIPE_BUF_ADDR_STATE, Av1BasicFeature)
-{    
+{
+    ENCODE_FUNC_CALL();
     ENCODE_CHK_NULL_RETURN(m_mmcState);
     if (m_mmcState->IsMmcEnabled())
     {
@@ -814,6 +826,7 @@ MHW_SETPAR_DECL_SRC(VDENC_PIPE_BUF_ADDR_STATE, Av1BasicFeature)
 
 MHW_SETPAR_DECL_SRC(VDENC_WEIGHTSOFFSETS_STATE, Av1BasicFeature)
 {
+    ENCODE_FUNC_CALL();
     int8_t size = sizeof(params.weightsLuma) / sizeof(int8_t);
     memset(params.weightsLuma, 1, size);
     memset(params.offsetsLuma, 0, size);
@@ -827,6 +840,7 @@ MHW_SETPAR_DECL_SRC(VDENC_WEIGHTSOFFSETS_STATE, Av1BasicFeature)
 
 MHW_SETPAR_DECL_SRC(VDENC_CMD1, Av1BasicFeature)
 {
+    ENCODE_FUNC_CALL();
 
     auto setting = static_cast<Av1VdencFeatureSettings*>(m_constSettings);
     ENCODE_CHK_NULL_RETURN(setting);
@@ -841,6 +855,7 @@ MHW_SETPAR_DECL_SRC(VDENC_CMD1, Av1BasicFeature)
 
 MHW_SETPAR_DECL_SRC(VDENC_HEVC_VP9_TILE_SLICE_STATE, Av1BasicFeature)
 {
+    ENCODE_FUNC_CALL();
     params.tileWidth  = m_oriFrameWidth;
     params.tileHeight = m_oriFrameHeight;
 
@@ -856,7 +871,6 @@ MHW_SETPAR_DECL_SRC(VDENC_CMD2, Av1BasicFeature)
     params.qpPrimeYDc  = (uint8_t)CodecHal_Clip3(0, 255, m_av1PicParams->base_qindex + m_av1PicParams->y_dc_delta_q);
     params.qpPrimeYAc  = (uint8_t)m_av1PicParams->base_qindex;
     params.tiling      = m_av1PicParams->tile_cols > 1 || m_av1PicParams->tile_rows > 1;
-    params.temporalMvp = false;
 
     ENCODE_CHK_STATUS_RETURN(m_ref.MHW_SETPAR_F(VDENC_CMD2)(params));
     ENCODE_CHK_STATUS_RETURN(m_streamIn.MHW_SETPAR_F(VDENC_CMD2)(params));
@@ -884,6 +898,7 @@ MHW_SETPAR_DECL_SRC(VDENC_CMD2, Av1BasicFeature)
 
 MHW_SETPAR_DECL_SRC(AVP_PIC_STATE, Av1BasicFeature)
 {
+    ENCODE_FUNC_CALL();
     // (1) from seq ddi params
     params.enableOrderHint     = m_av1SeqParams->CodingToolFlags.fields.enable_order_hint ? true : false;
     params.orderHintBitsMinus1 = m_av1SeqParams->order_hint_bits_minus_1;
@@ -988,6 +1003,7 @@ MHW_SETPAR_DECL_SRC(AVP_PIC_STATE, Av1BasicFeature)
 
 MHW_SETPAR_DECL_SRC(AVP_INLOOP_FILTER_STATE, Av1BasicFeature)
 {
+    ENCODE_FUNC_CALL();
     params.loopFilterLevel[0] = m_av1PicParams->filter_level[0];
     params.loopFilterLevel[1] = m_av1PicParams->filter_level[1];
     params.loopFilterLevel[2] = m_av1PicParams->filter_level_u;
@@ -1037,6 +1053,7 @@ MHW_SETPAR_DECL_SRC(AVP_INLOOP_FILTER_STATE, Av1BasicFeature)
 
 MHW_SETPAR_DECL_SRC(AVP_PIPE_BUF_ADDR_STATE, Av1BasicFeature)
 {
+    ENCODE_FUNC_CALL();
     params.bsLineRowstoreBuffer            = m_bitstreamDecoderEncoderLineRowstoreReadWriteBuffer;
     params.intraPredLineRowstoreBuffer     = m_resMfdIntraRowStoreScratchBuffer;
     params.intraPredTileLineRowstoreBuffer = m_intraPredictionTileLineRowstoreReadWriteBuffer;
@@ -1097,6 +1114,7 @@ MHW_SETPAR_DECL_SRC(AVP_PIPE_BUF_ADDR_STATE, Av1BasicFeature)
 
 MHW_SETPAR_DECL_SRC(AVP_INTER_PRED_STATE, Av1BasicFeature)
 {
+    ENCODE_FUNC_CALL();
     MHW_CHK_STATUS_RETURN(m_ref.MHW_SETPAR_F(AVP_INTER_PRED_STATE)(params));
 
     return MOS_STATUS_SUCCESS;
@@ -1104,6 +1122,7 @@ MHW_SETPAR_DECL_SRC(AVP_INTER_PRED_STATE, Av1BasicFeature)
 
 MHW_SETPAR_DECL_SRC(AVP_IND_OBJ_BASE_ADDR_STATE, Av1BasicFeature)
 {
+    ENCODE_FUNC_CALL();
     params.Mode                = codechalEncodeModeAv1;
     params.mvObjectBuffer      = m_resMbCodeBuffer;
     params.pakBaseObjectBuffer = const_cast<PMOS_RESOURCE>(&m_resBitstreamBuffer);
@@ -1114,6 +1133,7 @@ MHW_SETPAR_DECL_SRC(AVP_IND_OBJ_BASE_ADDR_STATE, Av1BasicFeature)
 
 MHW_SETPAR_DECL_SRC(AVP_SURFACE_STATE, Av1BasicFeature)
 {
+    ENCODE_FUNC_CALL();
     MOS_MEMCOMP_STATE mmcState = {};
     switch (params.surfaceStateId)
     {
@@ -1184,6 +1204,7 @@ enum CODEC_STANDARD_SELECT
 
 MHW_SETPAR_DECL_SRC(AVP_PIPE_MODE_SELECT, Av1BasicFeature)
 {
+    ENCODE_FUNC_CALL();
     params.codecSelect         = CODEC_SELECT_ENCODE;
     params.codecStandardSelect = CODEC_STANDARD_SELECT_AV1;
     params.vdencMode           = true;
@@ -1214,6 +1235,7 @@ MHW_SETPAR_DECL_SRC(AVP_PIPE_MODE_SELECT, Av1BasicFeature)
 
 MHW_SETPAR_DECL_SRC(AVP_TILE_CODING, Av1BasicFeature)
 {
+    ENCODE_FUNC_CALL();
     params.tileRowIndependentFlag  = false;
     params.disableCdfUpdateFlag    = m_av1PicParams->PicFlags.fields.disable_cdf_update ? 1 : 0;
     params.numOfActiveBePipes      = 1;
@@ -1225,6 +1247,7 @@ MHW_SETPAR_DECL_SRC(AVP_TILE_CODING, Av1BasicFeature)
 
 MHW_SETPAR_DECL_SRC(HUC_PIPE_MODE_SELECT, Av1BasicFeature)
 {
+    ENCODE_FUNC_CALL();
     params.mode = m_mode;
 
     return MOS_STATUS_SUCCESS;
@@ -1232,6 +1255,7 @@ MHW_SETPAR_DECL_SRC(HUC_PIPE_MODE_SELECT, Av1BasicFeature)
 
 MHW_SETPAR_DECL_SRC(MFX_WAIT, Av1BasicFeature)
 {
+    ENCODE_FUNC_CALL();
     params.iStallVdboxPipeline = true;
 
     return MOS_STATUS_SUCCESS;
