@@ -26,23 +26,25 @@
 
 #include "encode_vdenc_lpla_analysis.h"
 #include "encode_hevc_vdenc_feature_manager.h"
+#include "encode_vdenc_hevc_fastpass.h"
 
 namespace encode
 {
     VdencLplaAnalysis::VdencLplaAnalysis(
         MediaFeatureManager *featureManager,
         EncodeAllocator     *allocator,
-        CodechalHwInterface *hwInterface,
+        CodechalHwInterfaceNext *hwInterface,
         void                *constSettings) :
         MediaFeature(constSettings, hwInterface ? hwInterface->GetOsInterface() : nullptr),
         m_hwInterface(hwInterface),
         m_allocator(allocator)
     {
-        auto encFeatureManager = dynamic_cast<EncodeHevcVdencFeatureManager *>(featureManager);
-        ENCODE_CHK_NULL_NO_STATUS_RETURN(encFeatureManager);
+        m_featureManager = dynamic_cast<EncodeHevcVdencFeatureManager *>(featureManager);
+        ENCODE_CHK_NULL_NO_STATUS_RETURN(m_featureManager);
 
-        m_basicFeature = dynamic_cast<EncodeBasicFeature *>(encFeatureManager->GetFeature(FeatureIDs::basicFeature));
+        m_basicFeature = dynamic_cast<EncodeBasicFeature *>(m_featureManager->GetFeature(FeatureIDs::basicFeature));
         ENCODE_CHK_NULL_NO_STATUS_RETURN(m_basicFeature);
+
         ENCODE_CHK_NULL_NO_STATUS_RETURN(hwInterface);
         m_osInterface = hwInterface->GetOsInterface();
 
@@ -141,7 +143,7 @@ namespace encode
             }
             else
             {
-                CODECHAL_ENCODE_ASSERTMESSAGE("Invalid GopPicSize in LPLA!");
+                ENCODE_ASSERTMESSAGE("Invalid GopPicSize in LPLA!");
                 return MOS_STATUS_INVALID_PARAMETER;
             }
         }
@@ -232,7 +234,7 @@ namespace encode
         uint8_t *data = (uint8_t *)m_osInterface->pfnLockResource(m_osInterface, m_forceIntraStreamInBuf, &lockFlags);
         ENCODE_CHK_NULL_RETURN(data);
 
-        MHW_VDBOX_VDENC_STREAMIN_STATE_PARAMS streaminDataParams;
+        mhw::vdbox::vdenc::VDENC_STREAMIN_STATE_PAR streaminDataParams;
         uint32_t streamInWidth  = (MOS_ALIGN_CEIL(m_basicFeature->m_frameWidth, 64) / 32);
         uint32_t streamInHeight = (MOS_ALIGN_CEIL(m_basicFeature->m_frameHeight, 64) / 32);
 
@@ -270,7 +272,7 @@ namespace encode
 
     MOS_STATUS VdencLplaAnalysis::SetStreaminDataPerRegion(
         uint32_t streamInWidth, uint32_t top, uint32_t bottom, uint32_t left, uint32_t right,
-        PMHW_VDBOX_VDENC_STREAMIN_STATE_PARAMS streaminParams, void *streaminData)
+        mhw::vdbox::vdenc::VDENC_STREAMIN_STATE_PAR *streaminParams, void *streaminData)
     {
         ENCODE_FUNC_CALL();
 
@@ -320,7 +322,7 @@ namespace encode
     }
 
     MOS_STATUS VdencLplaAnalysis::SetStreaminDataPerLcu(
-        PMHW_VDBOX_VDENC_STREAMIN_STATE_PARAMS streaminParams,
+        mhw::vdbox::vdenc::VDENC_STREAMIN_STATE_PAR *streaminParams,
         void * streaminData)
     {
         ENCODE_FUNC_CALL();
@@ -366,14 +368,15 @@ namespace encode
         allocParamsForBufferLinear.Type     = MOS_GFXRES_BUFFER;
         allocParamsForBufferLinear.TileType = MOS_TILE_LINEAR;
         allocParamsForBufferLinear.Format   = Format_Buffer;
+        allocParamsForBufferLinear.ResUsageType = MOS_HW_RESOURCE_USAGE_ENCODE_INTERNAL_READ_WRITE_NOCACHE;
 
         // Buffer to store VDEnc frame statistics for lookahead BRC
-        m_brcLooaheadStatsBufferSize        = m_numLaDataEntry * sizeof(VdencHevcLaStats);
+        m_brcLooaheadStatsBufferSize        = m_numLaDataEntry * sizeof(VdencHevcLaStatsForLAKernel);
         allocParamsForBufferLinear.dwBytes  = MOS_ALIGN_CEIL(m_brcLooaheadStatsBufferSize, CODECHAL_PAGE_SIZE);
         allocParamsForBufferLinear.pBufName = "VDENC Lookahead Statistics Buffer";
         m_vdencLaStatsBuffer                = m_allocator->AllocateResource(allocParamsForBufferLinear, true);
 
-        VdencHevcLaStats *lookaheadInfo = (VdencHevcLaStats *)m_allocator->LockResourceForWrite(m_vdencLaStatsBuffer);
+        VdencHevcLaStatsForLAKernel *lookaheadInfo = (VdencHevcLaStatsForLAKernel *)m_allocator->LockResourceForWrite(m_vdencLaStatsBuffer);
         ENCODE_CHK_NULL_RETURN(lookaheadInfo);
         MOS_ZeroMemory(lookaheadInfo, allocParamsForBufferLinear.dwBytes);
         m_allocator->UnLock(m_vdencLaStatsBuffer);
@@ -431,6 +434,7 @@ namespace encode
 
         ENCODE_CHK_NULL_RETURN(params);
         EncoderParams *encodeParams = (EncoderParams *)params;
+        m_encodeParams              = (EncoderParams *)params;
         m_hevcSeqParams = static_cast<PCODEC_HEVC_ENCODE_SEQUENCE_PARAMS>(encodeParams->pSeqParams);
         ENCODE_CHK_NULL_RETURN(m_hevcSeqParams);
         m_lookaheadDepth = m_hevcSeqParams->LookaheadDepth;
@@ -453,7 +457,19 @@ namespace encode
         m_hevcSliceParams = static_cast<PCODEC_HEVC_ENCODE_SLICE_PARAMS>(encodeParams->pSliceParams);
         ENCODE_CHK_STATUS_RETURN(SetupForceIntraStreamIn());
 
-        m_numValidLaRecords++;
+        if (!m_lastPicInStream)
+        {
+            m_numValidLaRecords++;
+        }
+
+        if (m_lastPicInStream && m_bLastPicFlagFirstIn)
+        {
+            m_currLaDataIdx -= 1;
+            m_bLastPicFlagFirstIn = false;
+        }
+
+        m_skipAnalysisKernelCall = m_hevcSeqParams->FullPassCodecType == 1 && m_basicFeature->m_laDataBufferEnabled
+                                   && !m_lookaheadAdaptiveI && !m_hevcSeqParams->GopFlags.fields.AdaptiveGop;
 
         return eStatus;
     }
@@ -470,20 +486,6 @@ namespace encode
             return eStatus;
         }
 
-#if (_SW_BRC)
-        CodechalVdencHevcLaData *data = (CodechalVdencHevcLaData *)m_allocator->LockResourceForRead(m_vdencLaDataBuffer);
-        ENCODE_CHK_NULL_RETURN(data);
-
-        LookaheadReport *lookaheadStatus     = &encodeStatusMfx->lookaheadStatus;
-        lookaheadStatus->targetFrameSize     = data[m_offset].targetFrameSize;
-        lookaheadStatus->targetBufferFulness = data[m_offset].targetBufferFulness;
-        lookaheadStatus->encodeHints         = data[m_offset].encodeHints;
-        lookaheadStatus->pyramidDeltaQP      = data[m_offset].pyramidDeltaQP;
-        lookaheadStatus->miniGopSize         = data[m_offset].miniGopSize;
-
-        m_allocator->UnLock(m_vdencLaDataBuffer);
-#endif
-
         if (m_lookaheadReport && (encodeStatusMfx->lookaheadStatus.targetFrameSize > 0))
         {
             statusReportData->pLookaheadStatus = &encodeStatusMfx->lookaheadStatus;
@@ -492,32 +494,6 @@ namespace encode
             encodeStatusMfx->lookaheadStatus.targetFrameSize = (uint32_t)((targetFrameSize + (32 * 8)) / (64 * 8));  // Convert bits to bytes. 64 is normalized average frame size used in lookahead analysis kernel
             uint64_t targetBufferFulness = (uint64_t)encodeStatusMfx->lookaheadStatus.targetBufferFulness * m_averageFrameSize;
             encodeStatusMfx->lookaheadStatus.targetBufferFulness = (uint32_t)((targetBufferFulness + 32) / 64);  // 64 is normalized average frame size used in lookahead analysis kernel
-            // Apply rounding error to targetFrameSize to align target buffer fullness between lookahead pass and encode pass
-            if (m_prevTargetFrameSize > 0)
-            {
-                int64_t encTargetBufferFulness = (int64_t)m_targetBufferFulness;
-                encTargetBufferFulness += (int64_t)(m_prevTargetFrameSize << 3) - (int64_t)m_averageFrameSize;
-                m_targetBufferFulness = encTargetBufferFulness < 0 ? 0 : (encTargetBufferFulness > 0xFFFFFFFF ? 0xFFFFFFFF : (uint32_t)encTargetBufferFulness);
-                int32_t deltaBits     = (int32_t)((int64_t)(encodeStatusMfx->lookaheadStatus.targetBufferFulness) + m_bufferFulnessError - (int64_t)(m_targetBufferFulness));
-                deltaBits /= 64;
-                if (deltaBits > 8)
-                {
-                    if ((uint32_t)deltaBits > encodeStatusMfx->lookaheadStatus.targetFrameSize)
-                    {
-                        deltaBits = (int32_t)(encodeStatusMfx->lookaheadStatus.targetFrameSize);
-                    }
-                    encodeStatusMfx->lookaheadStatus.targetFrameSize += (uint32_t)(deltaBits >> 3);
-                }
-                else if (deltaBits < -8)
-                {
-                    if ((-deltaBits) > (int32_t)(encodeStatusMfx->lookaheadStatus.targetFrameSize))
-                    {
-                        deltaBits = -(int32_t)(encodeStatusMfx->lookaheadStatus.targetFrameSize);
-                    }
-                    encodeStatusMfx->lookaheadStatus.targetFrameSize -= (uint32_t)((-deltaBits) >> 3);
-                }
-            }
-            m_prevTargetFrameSize = encodeStatusMfx->lookaheadStatus.targetFrameSize;
 
             if (encodeStatusMfx->lookaheadStatus.miniGopSize == 2)
             {
@@ -558,37 +534,51 @@ namespace encode
         ENCODE_CHK_NULL_RETURN(debugInterface);
         int32_t currentPass = pipeline->GetCurrentPass();
 
-        ENCODE_CHK_STATUS_RETURN(debugInterface->DumpBuffer(
+        ENCODE_CHK_STATUS_RETURN(debugInterface->DumpHucDmem(
             m_vdencLaUpdateDmemBuffer[pipeline->m_currRecycledBufIdx][currentPass],
-            CodechalDbgAttr::attrVdencOutput,
-            "_LookaheadDmem",
             sizeof(VdencHevcHucLaDmem),
-            0,
-            CODECHAL_NUM_MEDIA_STATES));
+            currentPass,
+            hucRegionDumpLAUpdate));
 
-        ENCODE_CHK_STATUS_RETURN(debugInterface->DumpBuffer(
-            m_vdencLaDataBuffer,
-            CodechalDbgAttr::attrVdencOutput,
-            "_LookaheadData",
-            m_brcLooaheadDataBufferSize,
-            0,
-            CODECHAL_NUM_MEDIA_STATES));
-
-        ENCODE_CHK_STATUS_RETURN(debugInterface->DumpBuffer(
+        ENCODE_CHK_STATUS_RETURN(debugInterface->DumpHucRegion(
             m_vdencLaHistoryBuffer,
-            CodechalDbgAttr::attrVdencOutput,
-            "_LookaheadHistory",
+            0,
             m_LaHistoryBufSize,
             0,
-            CODECHAL_NUM_MEDIA_STATES));
+            "_History",
+            isInput,
+            currentPass,
+            hucRegionDumpLAUpdate));
 
-        ENCODE_CHK_STATUS_RETURN(debugInterface->DumpBuffer(
+        ENCODE_CHK_STATUS_RETURN(debugInterface->DumpHucRegion(
             m_vdencLaStatsBuffer,
-            CodechalDbgAttr::attrVdencOutput,
-            "_LookaheadStats",
-            m_brcLooaheadStatsBufferSize,
             0,
-            CODECHAL_NUM_MEDIA_STATES));
+            m_brcLooaheadStatsBufferSize,
+            1,
+            "_Stats",
+            isInput,
+            currentPass,
+            hucRegionDumpLAUpdate));
+
+        ENCODE_CHK_STATUS_RETURN(debugInterface->DumpHucRegion(
+            m_encodeParams->presLaDataBuffer,
+            0,
+            m_brcLooaheadStatsBufferSize,
+            1,
+            "_Stats_laBuffer",
+            isInput,
+            currentPass,
+            hucRegionDumpLAUpdate));
+
+        ENCODE_CHK_STATUS_RETURN(debugInterface->DumpHucRegion(
+            m_vdencLaDataBuffer,
+            0,
+            m_brcLooaheadDataBufferSize,
+            2,
+            "_Data",
+            isInput,
+            currentPass,
+            hucRegionDumpLAUpdate));
 
         return eStatus;
     }
@@ -614,9 +604,9 @@ namespace encode
             return eStatus;
         }
 
-        uint8_t index;
+        uint8_t index = 0;
         ENCODE_CHK_STATUS_RETURN(GetLaStatsStoreIdx(index));
-        uint32_t offset = sizeof(VdencHevcLaStats) * index;        
+        uint32_t offset = sizeof(VdencHevcLaStatsForLAKernel) * index;        
         if (m_useDSData)
         {
             auto &storeFrameByteCount            = m_miItf->MHW_GETPAR_F(MI_STORE_DATA_IMM)();
@@ -640,200 +630,195 @@ namespace encode
             storeIntraCuCount.dwValue          = m_statsBuffer[index][2];
             ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_STORE_DATA_IMM)(&cmdBuffer));
 
-            auto &flushDwParams = m_miItf->MHW_GETPAR_F(MI_STORE_DATA_IMM)();
+            auto &flushDwParams = m_miItf->MHW_GETPAR_F(MI_FLUSH_DW)();
             flushDwParams       = {};
-            MOS_ZeroMemory(&flushDwParams, sizeof(flushDwParams));
             // Make Flush DW call to make sure all previous work is done
-            ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_STORE_DATA_IMM)(&cmdBuffer));
+            ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_FLUSH_DW)(&cmdBuffer));
         }
         else
         {
-            auto &miStoreRegMemParams = m_miItf->MHW_GETPAR_F(MI_STORE_REGISTER_MEM)();
-            auto &miLoadRegMemParams  = m_miItf->MHW_GETPAR_F(MI_LOAD_REGISTER_MEM)();
-            auto &flushDwParams       = m_miItf->MHW_GETPAR_F(MI_FLUSH_DW)();
+            StoreLookaheadData(cmdBuffer, m_vdencLaStatsBuffer, offset, vdboxIndex);
+        }
 
-            miStoreRegMemParams = {};
-            miLoadRegMemParams  = {};
-            flushDwParams       = {};
+        //store stats in la buffer allocated by VPL
+        if (m_basicFeature->m_laDataBufferEnabled)
+        {
+            offset = sizeof(VdencHevcLaStatsForBRCKernel) * index;
+            StoreLookaheadData(cmdBuffer, m_encodeParams->presLaDataBuffer, offset, vdboxIndex);
 
-            auto mmioRegistersHcp          = m_hcpItf->GetMmioRegisters(vdboxIndex);
-            miStoreRegMemParams.dwRegister = mmioRegistersHcp->hcpEncBitstreamBytecountFrameRegOffset;
-            // Store BitstreamBytecount to m_vdencLaStatsBuffer
-            miStoreRegMemParams.presStoreBuffer = m_vdencLaStatsBuffer;
-            miStoreRegMemParams.dwOffset        = offset + CODECHAL_OFFSETOF(VdencHevcLaStats, frameByteCount);
-            ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_STORE_REGISTER_MEM)(&cmdBuffer));
-
-            // Calculate header size including LCU header
-            uint32_t headerBitSize = 0;
-            for (uint32_t i = 0; i < HEVC_MAX_NAL_UNIT_TYPE; i++)
-            {
-                headerBitSize += m_nalUnitParams[i]->uiSize * 8;
-            }
-            for (uint32_t i = 0; i < m_numSlices; i++)
-            {
-                headerBitSize += m_slcData[i].BitSize;
-            }
-
-            // Store headerBitCount to m_vdencLaStatsBuffer
-            auto &storeDataParams            = m_miItf->MHW_GETPAR_F(MI_STORE_DATA_IMM)();
-            storeDataParams                  = {};
-            storeDataParams.pOsResource      = m_vdencLaStatsBuffer;
-            storeDataParams.dwResourceOffset = offset + CODECHAL_OFFSETOF(VdencHevcLaStats, headerBitCount);
-            storeDataParams.dwValue          = headerBitSize;
+            auto &storeFrameNum            = m_miItf->MHW_GETPAR_F(MI_STORE_DATA_IMM)();
+            storeFrameNum                  = {};
+            storeFrameNum.pOsResource      = m_encodeParams->presLaDataBuffer;
+            storeFrameNum.dwResourceOffset = offset + CODECHAL_OFFSETOF(VdencHevcLaStatsForBRCKernel, frameNumber);
+            storeFrameNum.dwValue          = m_basicFeature->m_frameNum;
             ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_STORE_DATA_IMM)(&cmdBuffer));
 
-            auto mmioRegs = m_miItf->GetMmioRegisters();
-            ENCODE_CHK_NULL_RETURN(mmioRegs);
-            // VCS_GPR0_Lo = LCUHdrBits
-            miLoadRegMemParams.presStoreBuffer = m_basicFeature->m_recycleBuf->GetBuffer(FrameStatStreamOutBuffer, 0);  // LCUHdrBits is in m_resFrameStatStreamOutBuffer DW4
-            miLoadRegMemParams.dwOffset        = 4 * sizeof(uint32_t);
-            miLoadRegMemParams.dwRegister      = mmioRegs->generalPurposeRegister0LoOffset;  // VCS_GPR0_Lo
-            ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_LOAD_REGISTER_MEM)(&cmdBuffer));
+            // Copy rhoDomainStats array (76 elements)
+            auto &miCpyMemMemParams = m_miItf->MHW_GETPAR_F(MI_COPY_MEM_MEM)();
+            for (uint32_t i = 0; i < 76; i++)
+            {
+                miCpyMemMemParams = {};
+                miCpyMemMemParams.presSrc = m_basicFeature->m_recycleBuf->GetBuffer(FrameStatStreamOutBuffer, 0);
+                miCpyMemMemParams.dwSrcOffset = (64 + i) * 4;
+                miCpyMemMemParams.presDst = m_encodeParams->presLaDataBuffer;
+                miCpyMemMemParams.dwDstOffset = offset + CODECHAL_OFFSETOF(VdencHevcLaStatsForBRCKernel, rhoDomainStats[i]);
+                ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_COPY_MEM_MEM)(&cmdBuffer));
+            }
+
             ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_FLUSH_DW)(&cmdBuffer));
-
-            // load headerBitCount(in m_vdencLaStatsBuffer) to VCS_GPR4_Lo
-            miLoadRegMemParams.presStoreBuffer = m_vdencLaStatsBuffer;
-            miLoadRegMemParams.dwOffset        = offset + CODECHAL_OFFSETOF(VdencHevcLaStats, headerBitCount);
-            miLoadRegMemParams.dwRegister      = mmioRegs->generalPurposeRegister4LoOffset;
-            ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_LOAD_REGISTER_MEM)(&cmdBuffer));
-
-            mhw::mi::MHW_MI_ALU_PARAMS aluParams[4] = {};
-            int32_t                    aluCount     = 0;
-
-            //load1 srca, reg1
-            aluParams[aluCount].AluOpcode = MHW_MI_ALU_LOAD;
-            aluParams[aluCount].Operand1  = MHW_MI_ALU_SRCA;
-            aluParams[aluCount].Operand2  = MHW_MI_ALU_GPREG0;
-            ++aluCount;
-
-            //load2 srcb, reg2
-            aluParams[aluCount].AluOpcode = MHW_MI_ALU_LOAD;
-            aluParams[aluCount].Operand1  = MHW_MI_ALU_SRCB;
-            aluParams[aluCount].Operand2  = MHW_MI_ALU_GPREG4;
-            ++aluCount;
-
-            //add srca + srcb
-            aluParams[aluCount].AluOpcode = MHW_MI_ALU_ADD;
-            ++aluCount;
-
-            //store reg1, accu
-            aluParams[aluCount].AluOpcode = MHW_MI_ALU_STORE;
-            aluParams[aluCount].Operand1  = MHW_MI_ALU_GPREG0;
-            aluParams[aluCount].Operand2  = MHW_MI_ALU_ACCU;
-            ++aluCount;
-
-            auto &miMathParams          = m_miItf->MHW_GETPAR_F(MI_MATH)();
-            miMathParams                = {};
-            miMathParams.dwNumAluParams = aluCount;
-            miMathParams.pAluPayload    = aluParams;
-            ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_MATH)(&cmdBuffer));
-            ENCODE_CHK_STATUS_RETURN(Mos_AddCommand(
-                &cmdBuffer,
-                &miMathParams.pAluPayload[0],
-                sizeof(mhw::mi::MHW_MI_ALU_PARAMS) * miMathParams.dwNumAluParams));
-
-            //store VCS_GPR0_Lo to m_vdencLaStatsBuffer
-            miStoreRegMemParams.presStoreBuffer = m_vdencLaStatsBuffer;
-            miStoreRegMemParams.dwOffset        = offset + CODECHAL_OFFSETOF(VdencHevcLaStats, headerBitCount);
-            miStoreRegMemParams.dwRegister      = mmioRegs->generalPurposeRegister0LoOffset;
-            ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_STORE_REGISTER_MEM)(&cmdBuffer));
-
-            // Make Flush DW call to make sure all previous work is done
-            ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_FLUSH_DW)(&cmdBuffer));
-
-            ENCODE_CHK_STATUS_RETURN(StoreVdencStatistics(cmdBuffer, index));
         }
+
         return eStatus;
     }
 
-    MOS_STATUS VdencLplaAnalysis::StoreVdencStatistics(MOS_COMMAND_BUFFER &cmdBuffer, uint8_t index)
+    MOS_STATUS VdencLplaAnalysis::StoreLookaheadData(MOS_COMMAND_BUFFER &cmdBuffer, PMOS_RESOURCE resource, uint32_t offset, MHW_VDBOX_NODE_IND vdboxIndex)
     {
         ENCODE_FUNC_CALL();
-        MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
+        MOS_STATUS eStatus             = MOS_STATUS_SUCCESS;
 
-        uint32_t offset = sizeof(VdencHevcLaStats) * index;
+        auto &miStoreRegMemParams = m_miItf->MHW_GETPAR_F(MI_STORE_REGISTER_MEM)();
+        auto &miLoadRegMemParams  = m_miItf->MHW_GETPAR_F(MI_LOAD_REGISTER_MEM)();
+        auto &flushDwParams       = m_miItf->MHW_GETPAR_F(MI_FLUSH_DW)();
+
+        miStoreRegMemParams = {};
+        miLoadRegMemParams  = {};
+        flushDwParams       = {};
+
+        auto mmioRegistersHcp          = m_hcpItf->GetMmioRegisters(vdboxIndex);
+        miStoreRegMemParams.dwRegister = mmioRegistersHcp->hcpEncBitstreamBytecountFrameRegOffset;
+        // Store BitstreamBytecount to m_vdencLaStatsBuffer
+        miStoreRegMemParams.presStoreBuffer = resource;
+        miStoreRegMemParams.dwOffset        = offset + CODECHAL_OFFSETOF(VdencHevcLaStats, frameByteCount);
+        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_STORE_REGISTER_MEM)(&cmdBuffer));
+
+        // Calculate header size including LCU header
+        uint32_t headerBitSize = 0;
+        for (uint32_t i = 0; i < HEVC_MAX_NAL_UNIT_TYPE; i++)
+        {
+            headerBitSize += m_nalUnitParams[i]->uiSize * 8;
+        }
+        for (uint32_t i = 0; i < m_numSlices; i++)
+        {
+            headerBitSize += m_slcData[i].BitSize;
+        }
+
+        // Store headerBitCount to m_vdencLaStatsBuffer
+        auto &storeDataParams            = m_miItf->MHW_GETPAR_F(MI_STORE_DATA_IMM)();
+        storeDataParams                  = {};
+        storeDataParams.pOsResource      = resource;
+        storeDataParams.dwResourceOffset = offset + CODECHAL_OFFSETOF(VdencHevcLaStats, headerBitCount);
+        storeDataParams.dwValue          = headerBitSize;
+        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_STORE_DATA_IMM)(&cmdBuffer));
+
+        auto mmioRegs = m_miItf->GetMmioRegisters();
+        ENCODE_CHK_NULL_RETURN(mmioRegs);
+        // VCS_GPR0_Lo = LCUHdrBits
+        miLoadRegMemParams.presStoreBuffer = m_basicFeature->m_recycleBuf->GetBuffer(FrameStatStreamOutBuffer, 0);  // LCUHdrBits is in m_resFrameStatStreamOutBuffer DW4
+        miLoadRegMemParams.dwOffset        = 4 * sizeof(uint32_t);
+        miLoadRegMemParams.dwRegister      = mmioRegs->generalPurposeRegister0LoOffset;  // VCS_GPR0_Lo
+        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_LOAD_REGISTER_MEM)(&cmdBuffer));
+        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_FLUSH_DW)(&cmdBuffer));
+
+        // load headerBitCount(in m_vdencLaStatsBuffer) to VCS_GPR4_Lo
+        miLoadRegMemParams.presStoreBuffer = resource;
+        miLoadRegMemParams.dwOffset        = offset + CODECHAL_OFFSETOF(VdencHevcLaStats, headerBitCount);
+        miLoadRegMemParams.dwRegister      = mmioRegs->generalPurposeRegister4LoOffset;
+        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_LOAD_REGISTER_MEM)(&cmdBuffer));
+
+        mhw::mi::MHW_MI_ALU_PARAMS aluParams[4] = {};
+        int32_t                    aluCount     = 0;
+
+        //load1 srca, reg1
+        aluParams[aluCount].AluOpcode = MHW_MI_ALU_LOAD;
+        aluParams[aluCount].Operand1  = MHW_MI_ALU_SRCA;
+        aluParams[aluCount].Operand2  = MHW_MI_ALU_GPREG0;
+        ++aluCount;
+
+        //load2 srcb, reg2
+        aluParams[aluCount].AluOpcode = MHW_MI_ALU_LOAD;
+        aluParams[aluCount].Operand1  = MHW_MI_ALU_SRCB;
+        aluParams[aluCount].Operand2  = MHW_MI_ALU_GPREG4;
+        ++aluCount;
+
+        //add srca + srcb
+        aluParams[aluCount].AluOpcode = MHW_MI_ALU_ADD;
+        ++aluCount;
+
+        //store reg1, accu
+        aluParams[aluCount].AluOpcode = MHW_MI_ALU_STORE;
+        aluParams[aluCount].Operand1  = MHW_MI_ALU_GPREG0;
+        aluParams[aluCount].Operand2  = MHW_MI_ALU_ACCU;
+        ++aluCount;
+
+        auto &miMathParams          = m_miItf->MHW_GETPAR_F(MI_MATH)();
+        miMathParams                = {};
+        miMathParams.dwNumAluParams = aluCount;
+        miMathParams.pAluPayload    = aluParams;
+        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_MATH)(&cmdBuffer));
+
+        //store VCS_GPR0_Lo to m_vdencLaStatsBuffer
+        miStoreRegMemParams.presStoreBuffer = resource;
+        miStoreRegMemParams.dwOffset        = offset + CODECHAL_OFFSETOF(VdencHevcLaStats, headerBitCount);
+        miStoreRegMemParams.dwRegister      = mmioRegs->generalPurposeRegister0LoOffset;
+        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_STORE_REGISTER_MEM)(&cmdBuffer));
+
+        // Make Flush DW call to make sure all previous work is done
+        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_FLUSH_DW)(&cmdBuffer));
+
+        //StoreVdencStatistics()
         auto &miCpyMemMemParams       = m_miItf->MHW_GETPAR_F(MI_COPY_MEM_MEM)();
         miCpyMemMemParams             = {};
         miCpyMemMemParams.presSrc     = m_basicFeature->m_recycleBuf->GetBuffer(VdencStatsBuffer, 0);  // 8X8 Normalized intra CU count is in m_resVdencStatsBuffer DW1
         miCpyMemMemParams.dwSrcOffset = 4;
-        miCpyMemMemParams.presDst     = m_vdencLaStatsBuffer;
+        miCpyMemMemParams.presDst     = resource;
         miCpyMemMemParams.dwDstOffset = offset + CODECHAL_OFFSETOF(VdencHevcLaStats, intraCuCount);
         ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_COPY_MEM_MEM)(&cmdBuffer));
 
+        // Copy SAD field
+        miCpyMemMemParams = {};
+        miCpyMemMemParams.presSrc = m_basicFeature->m_recycleBuf->GetBuffer(VdencStatsBuffer, 0);
+        miCpyMemMemParams.dwSrcOffset = 0;
+        miCpyMemMemParams.presDst = resource;
+        miCpyMemMemParams.dwDstOffset = offset + CODECHAL_OFFSETOF(VdencHevcLaStats, sad);
+        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_COPY_MEM_MEM)(&cmdBuffer));
+
         return eStatus;
     }
 
-    MOS_STATUS VdencLplaAnalysis::ReadLPLAData(PMOS_COMMAND_BUFFER cmdBuffer, PMOS_RESOURCE resource, uint32_t baseOffset, bool hucStsUpdNeeded)
+    MOS_STATUS VdencLplaAnalysis::ReadLPLAData(PMOS_COMMAND_BUFFER cmdBuffer, PMOS_RESOURCE resource, uint32_t baseOffset)
     {
         ENCODE_FUNC_CALL();
-        if (!hucStsUpdNeeded)
-        {
-            // Write lookahead status to encode status buffer
-            auto &miCpyMemMemParams       = m_miItf->MHW_GETPAR_F(MI_COPY_MEM_MEM)();
-            auto &flushDwParams           = m_miItf->MHW_GETPAR_F(MI_FLUSH_DW)();
 
-            miCpyMemMemParams             = {};
-            miCpyMemMemParams.presSrc     = m_vdencLaDataBuffer;
-            miCpyMemMemParams.dwSrcOffset = m_offset * sizeof(CodechalVdencHevcLaData) + CODECHAL_OFFSETOF(CodechalVdencHevcLaData, encodeHints);
-            miCpyMemMemParams.presDst     = resource;
-            miCpyMemMemParams.dwDstOffset = baseOffset + CODECHAL_OFFSETOF(LookaheadReport, encodeHints);
-            ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_COPY_MEM_MEM)(cmdBuffer));
-            miCpyMemMemParams.dwSrcOffset = m_offset * sizeof(CodechalVdencHevcLaData) + CODECHAL_OFFSETOF(CodechalVdencHevcLaData, targetFrameSize);
-            miCpyMemMemParams.dwDstOffset = baseOffset + CODECHAL_OFFSETOF(LookaheadReport, targetFrameSize);
-            ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_COPY_MEM_MEM)(cmdBuffer));
-            miCpyMemMemParams.dwSrcOffset = m_offset * sizeof(CodechalVdencHevcLaData) + CODECHAL_OFFSETOF(CodechalVdencHevcLaData, targetBufferFulness);
-            miCpyMemMemParams.dwDstOffset = baseOffset + CODECHAL_OFFSETOF(LookaheadReport, targetBufferFulness);
-            ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_COPY_MEM_MEM)(cmdBuffer));
-            miCpyMemMemParams.dwSrcOffset = m_offset * sizeof(CodechalVdencHevcLaData) + CODECHAL_OFFSETOF(CodechalVdencHevcLaData, pyramidDeltaQP);
-            miCpyMemMemParams.dwDstOffset = baseOffset + CODECHAL_OFFSETOF(LookaheadReport, pyramidDeltaQP);
-            ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_COPY_MEM_MEM)(cmdBuffer));
-            miCpyMemMemParams.dwSrcOffset = m_offset * sizeof(CodechalVdencHevcLaData) + CODECHAL_OFFSETOF(CodechalVdencHevcLaData, miniGopSize);
-            miCpyMemMemParams.dwDstOffset = baseOffset + CODECHAL_OFFSETOF(LookaheadReport, miniGopSize);
-            ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_COPY_MEM_MEM)(cmdBuffer));
+        // Write lookahead status to encode status buffer
+        auto &miCpyMemMemParams = m_miItf->MHW_GETPAR_F(MI_COPY_MEM_MEM)();
+        auto &flushDwParams     = m_miItf->MHW_GETPAR_F(MI_FLUSH_DW)();
 
-            flushDwParams = {};
-            ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_FLUSH_DW)(cmdBuffer));
-        }
+        miCpyMemMemParams             = {};
+        miCpyMemMemParams.presSrc     = m_vdencLaDataBuffer;
+        miCpyMemMemParams.dwSrcOffset = m_offset * sizeof(CodechalVdencHevcLaData) + CODECHAL_OFFSETOF(CodechalVdencHevcLaData, encodeHints);
+        miCpyMemMemParams.presDst     = resource;
+        miCpyMemMemParams.dwDstOffset = baseOffset + CODECHAL_OFFSETOF(LookaheadReport, encodeHints);
+        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_COPY_MEM_MEM)(cmdBuffer));
+        miCpyMemMemParams.dwSrcOffset = m_offset * sizeof(CodechalVdencHevcLaData) + CODECHAL_OFFSETOF(CodechalVdencHevcLaData, targetFrameSize);
+        miCpyMemMemParams.dwDstOffset = baseOffset + CODECHAL_OFFSETOF(LookaheadReport, targetFrameSize);
+        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_COPY_MEM_MEM)(cmdBuffer));
+        miCpyMemMemParams.dwSrcOffset = m_offset * sizeof(CodechalVdencHevcLaData) + CODECHAL_OFFSETOF(CodechalVdencHevcLaData, targetBufferFulness);
+        miCpyMemMemParams.dwDstOffset = baseOffset + CODECHAL_OFFSETOF(LookaheadReport, targetBufferFulness);
+        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_COPY_MEM_MEM)(cmdBuffer));
+        miCpyMemMemParams.dwSrcOffset = m_offset * sizeof(CodechalVdencHevcLaData) + CODECHAL_OFFSETOF(CodechalVdencHevcLaData, pyramidDeltaQP);
+        miCpyMemMemParams.dwDstOffset = baseOffset + CODECHAL_OFFSETOF(LookaheadReport, pyramidDeltaQP);
+        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_COPY_MEM_MEM)(cmdBuffer));
+        //MI_COPY_MEM_MEM reads a DWord from memory and stores it to memory. This copy will include adaptive_rounding and minigop
+        miCpyMemMemParams.dwSrcOffset = m_offset * sizeof(CodechalVdencHevcLaData) + CODECHAL_OFFSETOF(CodechalVdencHevcLaData, adaptive_rounding);
+        miCpyMemMemParams.dwDstOffset = baseOffset + CODECHAL_OFFSETOF(LookaheadReport, adaptive_rounding);
+        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_COPY_MEM_MEM)(cmdBuffer));
+
+        flushDwParams = {};
+        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_FLUSH_DW)(cmdBuffer));
 
         return MOS_STATUS_SUCCESS;
     }
 
-    MOS_STATUS VdencLplaAnalysis::SetLaInitDmemParameters(MHW_VDBOX_HUC_DMEM_STATE_PARAMS &dmemParams)
-    {
-        ENCODE_FUNC_CALL();
-
-        if (!m_enabled)
-        {
-            return MOS_STATUS_SUCCESS;
-        }
-        ENCODE_CHK_STATUS_RETURN(SetLaInitDmemBuffer());
-
-        dmemParams.presHucDataSource = m_vdencLaInitDmemBuffer;
-        dmemParams.dwDataLength      = MOS_ALIGN_CEIL(m_vdencLaInitDmemBufferSize, CODECHAL_CACHELINE_SIZE);
-        dmemParams.dwDmemOffset      = HUC_DMEM_OFFSET_RTOS_GEMS;
-
-        return MOS_STATUS_SUCCESS;
-    }
-
-    MOS_STATUS VdencLplaAnalysis::SetLaUpdateDmemParameters(MHW_VDBOX_HUC_DMEM_STATE_PARAMS &dmemParams, uint8_t currRecycledBufIdx, uint16_t curPass, uint16_t numPasses)
-    {
-        ENCODE_FUNC_CALL();
-        MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
-
-        if (!m_enabled)
-        {
-            return eStatus;
-        }
-
-        ENCODE_CHK_STATUS_RETURN(SetLaUpdateDmemBuffer(currRecycledBufIdx, m_currLaDataIdx, m_numValidLaRecords, curPass, numPasses));
-
-        dmemParams.presHucDataSource = m_vdencLaUpdateDmemBuffer[currRecycledBufIdx][curPass];
-        dmemParams.dwDataLength = MOS_ALIGN_CEIL(m_vdencLaUpdateDmemBufferSize, CODECHAL_CACHELINE_SIZE);
-        dmemParams.dwDmemOffset = HUC_DMEM_OFFSET_RTOS_GEMS;
-
-        return eStatus;
-    }
-
     MOS_STATUS VdencLplaAnalysis::SetLaUpdateDmemParameters(HUC_DMEM_STATE_PAR_ALIAS &params, uint8_t currRecycledBufIdx, uint16_t curPass, uint16_t numPasses)
     {
         ENCODE_FUNC_CALL();
@@ -858,7 +843,10 @@ namespace encode
         ENCODE_FUNC_CALL();
         MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
 
-        m_currLaDataIdx  = (m_currLaDataIdx + 1) % m_numLaDataEntry;
+        if (!m_lastPicInStream)
+        {
+            m_currLaDataIdx = (m_currLaDataIdx + 1) % m_numLaDataEntry;
+        }
 
         return eStatus;
     }
@@ -867,17 +855,30 @@ namespace encode
     {
         ENCODE_FUNC_CALL();
         MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
-
+        ENCODE_CHK_NULL_RETURN(m_basicFeature);
         // Setup LAInit DMEM
         auto hucVdencLaInitDmem = (VdencHevcHucLaDmem *)m_allocator->LockResourceForWrite(m_vdencLaInitDmemBuffer);
         ENCODE_CHK_NULL_RETURN(hucVdencLaInitDmem);
-        MOS_ZeroMemory(hucVdencLaInitDmem, sizeof(hucVdencLaInitDmem));
+        MOS_ZeroMemory(hucVdencLaInitDmem, sizeof(VdencHevcHucLaDmem));
 
         uint32_t initVbvFullness = MOS_MIN(m_hevcSeqParams->InitVBVBufferFullnessInBit, m_hevcSeqParams->VBVBufferSizeInBit);
-        uint8_t downscaleRatioIndicator = 2;  // 4x downscaling
-        if (m_hevcPicParams->DownScaleRatio.fields.X16Minus1_X == 15 && m_hevcPicParams->DownScaleRatio.fields.X16Minus1_Y == 15)
+        
+        auto fastPassFeature = dynamic_cast<HevcVdencFastPass *>(m_featureManager->GetFeature(HevcFeatureIDs::hevcVdencFastPassFeature));
+        if (fastPassFeature && m_hevcSeqParams->EnableFastPass)
         {
-            downscaleRatioIndicator = 0;  // no downscaling
+            hucVdencLaInitDmem->downscaleRatio = m_hevcSeqParams->FastPassRatio;
+            hucVdencLaInitDmem->enc_frame_width = fastPassFeature->GetFastPassDsWidth();
+            hucVdencLaInitDmem->enc_frame_height = fastPassFeature->GetFastPassDsHeight();
+        }
+        else
+        {
+            hucVdencLaInitDmem->downscaleRatio = 2;  // 4x downscaling
+            if (m_hevcPicParams->DownScaleRatio.fields.X16Minus1_X == 15 && m_hevcPicParams->DownScaleRatio.fields.X16Minus1_Y == 15)
+            {
+                hucVdencLaInitDmem->downscaleRatio = 0;  // no downscaling
+            }
+            hucVdencLaInitDmem->enc_frame_width  = m_basicFeature->m_frameWidth;
+            hucVdencLaInitDmem->enc_frame_height = m_basicFeature->m_frameHeight;
         }
 
         hucVdencLaInitDmem->lookAheadFunc = 0;
@@ -886,10 +887,6 @@ namespace encode
         hucVdencLaInitDmem->vbvInitialFullness = initVbvFullness / m_averageFrameSize;
         hucVdencLaInitDmem->statsRecords = m_numLaDataEntry;
         hucVdencLaInitDmem->averageFrameSize = m_averageFrameSize >> 3;
-        hucVdencLaInitDmem->downscaleRatio = downscaleRatioIndicator;
-        ENCODE_CHK_NULL_RETURN(m_basicFeature);
-        hucVdencLaInitDmem->enc_frame_width = m_basicFeature->m_frameWidth;
-        hucVdencLaInitDmem->enc_frame_height = m_basicFeature->m_frameHeight;
         hucVdencLaInitDmem->codec_type = m_hevcSeqParams->FullPassCodecType;
         hucVdencLaInitDmem->mbr_ratio = (m_hevcSeqParams->TargetBitRate > 0 && m_hevcSeqParams->MaxBitRate >= m_hevcSeqParams->TargetBitRate) ?
                                         m_hevcSeqParams->MaxBitRate * 100 / m_hevcSeqParams->TargetBitRate : 100;
@@ -928,7 +925,7 @@ namespace encode
         // Setup LAUpdate DMEM
         auto hucVdencLaUpdateDmem = (VdencHevcHucLaDmem *)m_allocator->LockResourceForWrite(m_vdencLaUpdateDmemBuffer[currRecycledBufIdx][curPass]);
         ENCODE_CHK_NULL_RETURN(hucVdencLaUpdateDmem);
-        MOS_ZeroMemory(hucVdencLaUpdateDmem, sizeof(hucVdencLaUpdateDmem));
+        MOS_ZeroMemory(hucVdencLaUpdateDmem, sizeof(VdencHevcHucLaDmem));
 
         hucVdencLaUpdateDmem->lookAheadFunc = 1;
         hucVdencLaUpdateDmem->validStatsRecords = numValidLaRecords;
@@ -941,56 +938,6 @@ namespace encode
         return eStatus;
     }
 
-    MOS_STATUS VdencLplaAnalysis::SetLaInitRegions(MHW_VDBOX_HUC_VIRTUAL_ADDR_PARAMS &virtualAddrParams)
-    {
-        ENCODE_FUNC_CALL();
-        MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
-
-        if (!m_enabled)
-        {
-            return eStatus;
-        }
-        // Add Virtual addr
-        virtualAddrParams.regionParams[0].presRegion = m_vdencLaHistoryBuffer;
-        virtualAddrParams.regionParams[0].isWritable = true;
-        m_lookaheadInit                              = false;
-
-        return eStatus;
-    }
-
-    MOS_STATUS VdencLplaAnalysis::SetLaUpdateRegions(MHW_VDBOX_HUC_VIRTUAL_ADDR_PARAMS &virtualAddrParams)
-    {
-        ENCODE_FUNC_CALL();
-        MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
-
-        if (!m_enabled)
-        {
-            return eStatus;
-        }
-        // Add Virtual addr
-        virtualAddrParams.regionParams[0].presRegion = m_vdencLaHistoryBuffer;
-        virtualAddrParams.regionParams[0].isWritable = true;
-        virtualAddrParams.regionParams[1].presRegion = m_vdencLaStatsBuffer;
-        virtualAddrParams.regionParams[2].presRegion = m_vdencLaDataBuffer;
-        virtualAddrParams.regionParams[2].isWritable = true;
-
-        return eStatus;
-    }
-
-    MOS_STATUS VdencLplaAnalysis::SetVdencPipeModeSelectParams(MHW_VDBOX_PIPE_MODE_SELECT_PARAMS_G12 &pipeModeSelectParams)
-    {
-        ENCODE_FUNC_CALL();
-        MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
-        
-        if (!m_enabled)
-        {
-            return eStatus;
-        }
-        pipeModeSelectParams.bLookaheadPass = true;
-
-        return eStatus;
-    }
-
     MOS_STATUS VdencLplaAnalysis::SetVdencPipeBufAddrParams(bool enableStreamIn, MHW_VDBOX_PIPE_BUF_ADDR_PARAMS &pipeBufAddrParams)
     {
         ENCODE_FUNC_CALL();
@@ -1011,7 +958,7 @@ namespace encode
 
     bool VdencLplaAnalysis::IsLaAnalysisRequired()
     {
-        return m_enabled;
+        return m_enabled && !m_skipAnalysisKernelCall;
     }
 
     bool VdencLplaAnalysis::IsLaRecordsEmpty()
@@ -1028,7 +975,8 @@ namespace encode
     {
         ENCODE_FUNC_CALL();
 
-        if (blastPass && m_numValidLaRecords >= m_lookaheadDepth)
+        if ((blastPass && m_numValidLaRecords >= m_lookaheadDepth) ||
+            (m_lastPicInStream && m_numValidLaRecords))
         {
             m_numValidLaRecords--;
             m_lookaheadReport = true;
